@@ -13,7 +13,10 @@ import aws_cdk.aws_ec2._jsii
 import aws_cdk.aws_ecs._jsii
 import aws_cdk.aws_efs._jsii
 import aws_cdk.aws_elasticloadbalancingv2._jsii
+import aws_cdk.aws_events._jsii
+import aws_cdk.aws_events_targets._jsii
 import aws_cdk.aws_iam._jsii
+import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_logs._jsii
 import aws_cdk.aws_rds._jsii
 import aws_cdk.aws_route53._jsii
@@ -24,9 +27,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-fargate-patterns",
-    "0.2.17",
+    "0.2.20",
     __name__[0:-6],
-    "cdk-fargate-patterns@0.2.17.jsii.tgz",
+    "cdk-fargate-patterns@0.2.20.jsii.tgz",
 )
 
 __all__ = [
